==> ejc-procurement-api-3.0.0-20251203.083445-19-sources.jar: com/ejianc/business/procurement/plan/vo/ReplyDetailVO.java <==
package com.ejianc.business.procurement.plan.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 计划答疑清单-待回复-子表
 * 
 * @author generator
 * 
 */
public class ReplyDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String purchaseItem; // 采购计划清单内容
    private String purchasePlanCode; // 采购计划来源单号
    private String items; // 疑问事项
    private String introducerName; // 提出人name
    private String phone; // 联系电话
    private String content; // 回复内容
    private String memo; // 备注
    private String replyName; // 回复人名称
    private Long midId; // 主表Id
    private Long purchasePlanId; // 采购计划来源id
    private Long introducerId; // 提出人id
    private Long replyId; // 回复人id
    

    public String getPurchaseItem() {
        return purchaseItem;
    }

    public void setPurchaseItem(String purchaseItem) {
        this.purchaseItem = purchaseItem;
    }
    public String getPurchasePlanCode() {
        return purchasePlanCode;
    }

    public void setPurchasePlanCode(String purchasePlanCode) {
        this.purchasePlanCode = purchasePlanCode;
    }
    public String getItems() {
        return items;
    }

    public void setItems(String items) {
        this.items = items;
    }
    public String getIntroducerName() {
        return introducerName;
    }

    public void setIntroducerName(String introducerName) {
        this.introducerName = introducerName;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getReplyName() {
        return replyName;
    }

    public void setReplyName(String replyName) {
        this.replyName = replyName;
    }
    public Long getMidId() {
        return midId;
    }

    public void setMidId(Long midId) {
        this.midId = midId;
    }
    public Long getPurchasePlanId() {
        return purchasePlanId;
    }

    public void setPurchasePlanId(Long purchasePlanId) {
        this.purchasePlanId = purchasePlanId;
    }
    public Long getIntroducerId() {
        return introducerId;
    }

    public void setIntroducerId(Long introducerId) {
        this.introducerId = introducerId;
    }
    public Long getReplyId() {
        return replyId;
    }

    public void setReplyId(Long replyId) {
        this.replyId = replyId;
    }
    
}

==> ejc-procurement-api-3.0.0-20251204.030939-35-sources.jar: com/ejianc/business/procurement/plan/vo/ReplyDetailVO.java <==
package com.ejianc.business.procurement.plan.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 计划答疑清单-待回复-子表
 * 
 * @author generator
 * 
 */
public class ReplyDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String purchaseItem; // 采购计划清单内容
    private String purchasePlanCode; // 采购计划来源单号
    private String items; // 疑问事项
    private String introducerName; // 提出人name
    private String phone; // 联系电话
    private String content; // 回复内容
    private String memo; // 备注
    private String replyName; // 回复人名称
    private Long midId; // 主表Id
    private Long purchasePlanId; // 采购计划来源id
    private Long introducerId; // 提出人id
    private Long replyId; // 回复人id
    private Long sourceId; //来源答疑清单单据主表Id
    private Long sourceDetailId; //来源答疑清单单据子表Id

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }

    public String getPurchaseItem() {
        return purchaseItem;
    }

    public void setPurchaseItem(String purchaseItem) {
        this.purchaseItem = purchaseItem;
    }
    public String getPurchasePlanCode() {
        return purchasePlanCode;
    }

    public void setPurchasePlanCode(String purchasePlanCode) {
        this.purchasePlanCode = purchasePlanCode;
    }
    public String getItems() {
        return items;
    }

    public void setItems(String items) {
        this.items = items;
    }
    public String getIntroducerName() {
        return introducerName;
    }

    public void setIntroducerName(String introducerName) {
        this.introducerName = introducerName;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getReplyName() {
        return replyName;
    }

    public void setReplyName(String replyName) {
        this.replyName = replyName;
    }
    public Long getMidId() {
        return midId;
    }

    public void setMidId(Long midId) {
        this.midId = midId;
    }
    public Long getPurchasePlanId() {
        return purchasePlanId;
    }

    public void setPurchasePlanId(Long purchasePlanId) {
        this.purchasePlanId = purchasePlanId;
    }
    public Long getIntroducerId() {
        return introducerId;
    }

    public void setIntroducerId(Long introducerId) {
        this.introducerId = introducerId;
    }
    public Long getReplyId() {
        return replyId;
    }

    public void setReplyId(Long replyId) {
        this.replyId = replyId;
    }
    
}
